#
# spec file for package mpv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Jiri Slaby <jslaby@suse.de>
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libmpv1
Name:           mpv
Version:        0.9.1
Release:        0
Summary:        Advanced General Purpose Video Player
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://mpv.io/
Source0:        https://github.com/mpv-player/mpv/archive/v%{version}.tar.gz
Source1:        %{name}.changes
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libavcodec-libav-devel
BuildRequires:  libavdevice-libav-devel
BuildRequires:  libavfilter-libav-devel
BuildRequires:  libavformat-libav-devel
BuildRequires:  libavutil-libav-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  libswscale-libav-devel
BuildRequires:  libv4l-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  lirc-devel
BuildRequires:  lua-devel
BuildRequires:  luajit-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  pulseaudio-devel
BuildRequires:  python-docutils
BuildRequires:  python-rst2pdf
BuildRequires:  python3
BuildRequires:  update-desktop-files
BuildRequires:  waf
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(caca)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libguess)
BuildRequires:  pkgconfig(libiso9660)
BuildRequires:  pkgconfig(libudf)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
# Used via LUA scripts
Recommends:     youtube-dl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

%package        devel
Summary:        A library to link together with mpv player
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains all the development files.

%package        -n %{libname}
Summary:        A library to link together with mpv player
Group:          System/Libraries

%description    -n %{libname}
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains a library that can other apps use to utilize the mpv
features.

%prep
%setup -q

# I hate UNKNOWN so lets put decent info there
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE1}")"
DATE="$(date -d "${modified}" "+%%b %%e %%Y")"
sed -i \
    -e "s:UNKNOWN:${DATE}:g" \
    common/version.c

%build
CCFLAGS="%{optflags}" \
waf configure \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --mandir="%{_mandir}" \
    --libdir="%{_libdir}" \
    --docdir="%{_docdir}/%{name}" \
    --confdir="%{_sysconfdir}/%{name}" \
    --enable-openal \
    --enable-cdda \
    --enable-libmpv-shared \
    --disable-sdl1 \
    --disable-sdl2 \
    --disable-build-date \
    --disable-debug

waf build --verbose %{?_smp_mflags}

%install
waf --destdir=%{buildroot} install %{?_smp_mflags}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%files
%defattr(-,root,root)
%doc LICENSE Copyright README.md etc/example.conf etc/input.conf
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/encoding-profiles.conf
%{_bindir}/%{name}
%doc %{_mandir}/man1/%{name}.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
